@@ -1597,8 +1597,23 @@ m.register '$/psi/select' {
     end
 }
 
+local function refreshLanguageConfiguration()
+    if not client.getOption('languageConfiguration') then
+        return
+    end
+    proto.notify('$/languageConfiguration', require 'provider.language-configuration')
+end
+
+config.watch(function (uri, key, value)
+    if key == '' then
+        refreshLanguageConfiguration()
+    end
+end)
 
 local function refreshStatusBar()
+    if not client.getOption('statusBar') then
+        return
+    end
     local valid = config.get(nil, 'Lua.window.statusBar')
     for _, scp in ipairs(workspace.folders) do
         if not config.get(scp.uri, 'Lua.window.statusBar') then
